@@ -1,23 +1,18 @@
 """
 Container, Well, WellGroup objects and associated functions
 
-    :copyright: 2018 by The Autoprotocol Development Team, see AUTHORS
+    :copyright: 2020 by The Autoprotocol Development Team, see AUTHORS
         for more details.
     :license: BSD, see LICENSE for more details
 
 """
 
-from __future__ import print_function, division
-import warnings
 import json
-import sys
+import warnings
+
 from .constants import SBS_FORMAT_SHAPES
 from .unit import Unit
 
-if sys.version_info.major == 3:
-    xrange = range  # pylint: disable=invalid-name
-    basestring = str  # pylint: disable=invalid-name
-
 SEAL_TYPES = ["ultra-clear", "foil", "breathable"]
 COVER_TYPES = ["standard", "low_evaporation", "universal"]
 
@@ -49,22 +44,21 @@ class Well(object):
     def validate_properties(properties):
         if not isinstance(properties, dict):
             raise TypeError(
-                "Aliquot properties {} are of type {}, "
-                "they should be a `dict`.".format(
-                    properties, type(properties)))
+                f"Aliquot properties {properties} are of type "
+                f"{type(properties)}, they should be a `dict`."
+            )
         for key, value in properties.items():
-            if not isinstance(key, basestring):
+            if not isinstance(key, str):
                 raise TypeError(
-                    "Aliquot property {} : {} has a key of type {}, "
-                    "it should be a 'str'.".format(key, value, type(key)))
+                    f"Aliquot property {key} : {value} has a key of type "
+                    f"{type(key)}, it should be a 'str'."
+                )
             try:
                 json.dumps(value)
             except TypeError:
                 raise TypeError(
-                    "Aliquot property {} : {} has a value of type {}, "
-                    "that isn't JSON serializable.".format(
-                        key, value, type(value)
-                    )
+                    f"Aliquot property {key} : {value} has a value of type "
+                    f"{type(value)}, that isn't JSON serializable."
                 )
 
     def set_properties(self, properties):
@@ -108,15 +102,12 @@ class Well(object):
         for key, value in properties.items():
             if key in self.properties:
                 values_are_lists = all(
-                    isinstance(_, list)
-                    for _ in [value, self.properties[key]]
+                    isinstance(_, list) for _ in [value, self.properties[key]]
                 )
                 if values_are_lists:
                     self.properties[key].extend(value)
                 else:
-                    message = "Overwriting existing property {} for {}".format(
-                        key, self
-                    )
+                    message = f"Overwriting existing property {key} for {self}"
                     warnings.warn(message=message)
                     self.properties[key] = value
             else:
@@ -144,16 +135,18 @@ class Well(object):
         ValueError
             Volume set exceeds maximum well volume
         """
-        if not isinstance(vol, basestring) and not isinstance(vol, Unit):
+        if not isinstance(vol, str) and not isinstance(vol, Unit):
             raise TypeError(
-                "Volume {} is of type {}, it should be either 'str' or 'Unit'."
-                "".format(vol, type(vol)))
+                f"Volume {vol} is of type {type(vol)}, it should be either "
+                f"'str' or 'Unit'."
+            )
         v = Unit(vol)
         max_vol = self.container.container_type.true_max_vol_ul
         if v > max_vol:
             raise ValueError(
-                "Theoretical volume {} to be set exceeds "
-                "maximum well volume {}.".format(v, max_vol))
+                f"Theoretical volume {v} to be set exceeds maximum well "
+                f"volume {max_vol}."
+            )
         self.volume = v
         return self
 
@@ -206,7 +199,7 @@ class Well(object):
             Well has no volume
         """
         if self.volume is None:
-            raise RuntimeError("well {} has no volume".format(self))
+            raise RuntimeError(f"well {self} has no volume")
         return self.volume - self.container.container_type.dead_volume_ul
 
     def __repr__(self):
@@ -214,8 +207,7 @@ class Well(object):
         Return a string representation of a Well.
 
         """
-        return "Well(%s, %s, %s)" % (str(self.container), str(self.index),
-                                     str(self.volume))
+        return f"Well({str(self.container)}, {str(self.index)}, " f"{str(self.volume)})"
 
 
 class WellGroup(object):
@@ -327,7 +319,8 @@ class WellGroup(object):
         for w in self.wells:
             assert w.container == self.wells[0].container, (
                 "All wells in WellGroup must belong to the same container to "
-                "get their indices.")
+                "get their indices."
+            )
             indices.append(w.humanize())
 
         return indices
@@ -378,8 +371,7 @@ class WellGroup(object):
 
         """
         if not isinstance(other, (WellGroup, list)):
-            raise TypeError("Input given is not of type 'WellGroup' or "
-                            "'list'.")
+            raise TypeError("Input given is not of type 'WellGroup' or " "'list'.")
         else:
             if not all(isinstance(well, Well) for well in other):
                 raise TypeError("Input given is not of type 'Well'.")
@@ -425,10 +417,15 @@ class WellGroup(object):
 
         """
         if not isinstance(prop, str):
-            raise TypeError("property is not a string: %r" % prop)
+            raise TypeError(f"property is not a string: {prop!r}")
         if val is not None:
-            return WellGroup([w for w in self.wells if prop in w.properties and
-                             w.properties[prop] is val])
+            return WellGroup(
+                [
+                    w
+                    for w in self.wells
+                    if prop in w.properties and w.properties[prop] is val
+                ]
+            )
         else:
             return WellGroup([w for w in self.wells if prop in w.properties])
 
@@ -555,8 +552,7 @@ class WellGroup(object):
 
         """
         if not isinstance(other, (Well, WellGroup)):
-            raise TypeError("You can only add a Well or WellGroups "
-                            "together.")
+            raise TypeError("You can only add a Well or WellGroups " "together.")
         if isinstance(other, Well):
             return WellGroup(self.wells + [other])
         else:
@@ -598,18 +594,15 @@ class Container(object):
 
     """
 
-    def __init__(self, id, container_type, name=None, storage=None,
-                 cover=None):
+    def __init__(self, id, container_type, name=None, storage=None, cover=None):
         self.name = name
         self.id = id
         self.container_type = container_type
         self.storage = storage
         self.cover = cover
-        self._wells = [Well(self, idx)
-                       for idx in xrange(container_type.well_count)]
+        self._wells = [Well(self, idx) for idx in range(container_type.well_count)]
         if self.cover and not (self.is_covered() or self.is_sealed()):
-            raise AttributeError("%s is not a valid seal or cover "
-                                 "type." % cover)
+            raise AttributeError(f"{cover} is not a valid seal or cover type.")
 
     def well(self, i):
         """
@@ -632,9 +625,8 @@ class Container(object):
         TypeError
             index given is not of the right type
         """
-        if not isinstance(i, (int, basestring)):
-            raise TypeError("Well reference given is not of type 'int' or "
-                            "'str'.")
+        if not isinstance(i, (int, str)):
+            raise TypeError("Well reference given is not of type 'int' or " "'str'.")
         return self._wells[self.robotize(i)]
 
     def well_from_coordinates(self, row, column):
@@ -677,8 +669,9 @@ class Container(object):
         if self.container_type.is_tube:
             return self.well(0)
         else:
-            raise AttributeError("%s is a %s and is not a tube" %
-                                 (self, self.container_type.shortname))
+            raise AttributeError(
+                f"{self} is a {self.container_type.shortname} " f"and is not a tube"
+            )
 
     def wells(self, *args):
         """
@@ -711,9 +704,10 @@ class Container(object):
             else:
                 wells.extend([a])
         for w in wells:
-            if not isinstance(w, (basestring, int, list)):
-                raise TypeError("Well reference given is not of type"
-                                " 'int', 'str' or 'list'.")
+            if not isinstance(w, (str, int, list)):
+                raise TypeError(
+                    "Well reference given is not of type" " 'int', 'str' or 'list'."
+                )
 
         return WellGroup([self.well(w) for w in wells])
 
@@ -726,9 +720,10 @@ class Container(object):
         `ContainerType.robotize()` for more information.
 
         """
-        if not isinstance(well_ref, (basestring, int, Well, list)):
-            raise TypeError("Well reference given is not of type 'str' "
-                            "'int', 'Well' or 'list'.")
+        if not isinstance(well_ref, (str, int, Well, list)):
+            raise TypeError(
+                "Well reference given is not of type 'str' " "'int', 'Well' or 'list'."
+            )
         return self.container_type.robotize(well_ref)
 
     def humanize(self, well_ref):
@@ -740,9 +735,10 @@ class Container(object):
         `ContainerType.humanize()` for more information.
 
         """
-        if not isinstance(well_ref, (int, basestring, list)):
-            raise TypeError("Well reference given is not of type 'int',"
-                            "'str' or 'list'.")
+        if not isinstance(well_ref, (int, str, list)):
+            raise TypeError(
+                "Well reference given is not of type 'int'," "'str' or 'list'."
+            )
         return self.container_type.humanize(well_ref)
 
     def decompose(self, well_ref):
@@ -754,9 +750,10 @@ class Container(object):
         `ContainerType.decompose()` for more information.
 
         """
-        if not isinstance(well_ref, (int, basestring, Well)):
-            raise TypeError("Well reference given is not of type 'int', "
-                            "'str' or Well.")
+        if not isinstance(well_ref, (int, str, Well)):
+            raise TypeError(
+                "Well reference given is not of type 'int', " "'str' or Well."
+            )
         return self.container_type.decompose(well_ref)
 
     def all_wells(self, columnwise=False):
@@ -778,9 +775,13 @@ class Container(object):
         if columnwise:
             num_cols = self.container_type.col_count
             num_rows = self.container_type.well_count // num_cols
-            return WellGroup([self._wells[row * num_cols + col]
-                              for col in xrange(num_cols)
-                              for row in xrange(num_rows)])
+            return WellGroup(
+                [
+                    self._wells[row * num_cols + col]
+                    for col in range(num_cols)
+                    for row in range(num_rows)
+                ]
+            )
         else:
             return WellGroup(self._wells)
 
@@ -805,15 +806,15 @@ class Container(object):
         num_rows = self.container_type.row_count()
         inner_wells = []
         if columnwise:
-            for c in xrange(1, num_cols - 1):
+            for c in range(1, num_cols - 1):
                 wells = []
-                for r in xrange(1, num_rows - 1):
+                for r in range(1, num_rows - 1):
                     wells.append((r * num_cols) + c)
                 inner_wells.extend(wells)
         else:
             well = num_cols
-            for _ in xrange(1, num_rows - 1):
-                inner_wells.extend(xrange(well + 1, well + (num_cols - 1)))
+            for _ in range(1, num_rows - 1):
+                inner_wells.extend(range(well + 1, well + (num_cols - 1)))
                 well += num_cols
         inner_wells = [self._wells[x] for x in inner_wells]
         return WellGroup(inner_wells)
@@ -846,9 +847,10 @@ class Container(object):
         TypeError
             Incorrect input types, e.g. `num` has to be of type int
         """
-        if not isinstance(start, (basestring, int, Well)):
-            raise TypeError("Well reference given is not of type 'str',"
-                            "'int', or 'Well'.")
+        if not isinstance(start, (str, int, Well)):
+            raise TypeError(
+                "Well reference given is not of type 'str'," "'int', or 'Well'."
+            )
         if not isinstance(num, int):
             raise TypeError("Number of wells given is not of type 'int'.")
 
@@ -857,7 +859,7 @@ class Container(object):
             row, col = self.decompose(start)
             num_rows = self.container_type.row_count()
             start = col * num_rows + row
-        return WellGroup(self.all_wells(columnwise).wells[start:start + num])
+        return WellGroup(self.all_wells(columnwise).wells[start : start + num])
 
     def is_sealed(self):
         """
@@ -909,28 +911,32 @@ class Container(object):
         # n_wells: n_cols
         allowed_layouts = {96: 12, 384: 24}
         n_wells = self.container_type.well_count
-        if (n_wells not in allowed_layouts or
-                self.container_type.col_count != allowed_layouts[n_wells]):
-            raise ValueError("Quadrant is only defined for standard 96 and "
-                             "384-well plates")
+        if (
+            n_wells not in allowed_layouts
+            or self.container_type.col_count != allowed_layouts[n_wells]
+        ):
+            raise ValueError(
+                "Quadrant is only defined for standard 96 and " "384-well plates"
+            )
 
         if n_wells == 96:
             if quad == 0:
                 return WellGroup(self._wells)
             else:
                 raise ValueError(
-                    "0 or 'A1' is the only valid quadrant for a 96-well "
-                    "plate.")
+                    "0 or 'A1' is the only valid quadrant for a 96-well " "plate."
+                )
 
         if quad not in [0, 1, 2, 3]:
-            raise ValueError("Invalid quadrant {} for plate type {}".format(
-                quad, str(self.name)))
+            raise ValueError(
+                f"Invalid quadrant {quad} for plate type " f"{str(self.name)}"
+            )
 
         start_well = [0, 1, 24, 25]
         wells = []
 
-        for row_offset in xrange(start_well[quad], 384, 48):
-            for col_offset in xrange(0, 24, 2):
+        for row_offset in range(start_well[quad], 384, 48):
+            for col_offset in range(0, 24, 2):
                 wells.append(row_offset + col_offset)
 
         return self.wells(wells)
@@ -956,9 +962,11 @@ class Container(object):
             If storage condition not of type str.
 
         """
-        if not isinstance(storage, basestring):
-            raise TypeError("Storage condition given ({0}) is not of type "
-                            "str. {1}.".format(storage, type(storage)))
+        if not isinstance(storage, str):
+            raise TypeError(
+                f"Storage condition given ({storage}) is not of "
+                f"type str. {type(storage)}."
+            )
 
         self.storage = storage
         return self
@@ -1037,37 +1045,34 @@ class Container(object):
         # getting the row and column values for the origin
         origin_row, origin_col = self.decompose(origin)
 
-        # origin coordinates transformed to SBS format space
-        sbs_row = int(origin_row / container_rows * format_rows)
-        sbs_col = int(origin_col / container_cols * format_cols)
-
-        # coordinates of the tail (bottom right well)
-        tail_row = sbs_row + shape["rows"]
-        tail_col = sbs_col + shape["columns"]
-        if tail_row > format_rows or tail_col > format_cols:
-            raise ValueError(
-                "origin: {} with shape: {} exceeds the bounds of "
-                "container: {}".format(origin, shape, self)
-            )
-
         # ratios of container shape to format shape
         row_scaling = container_rows / format_rows
         col_scaling = container_cols / format_cols
 
-        # the 0-indexed coordinates of all wells to be included
-        well_rows = [
-            int(_ * row_scaling)
-            for _ in range(sbs_row, sbs_row + shape["rows"])
-        ]
-        well_cols = [
-            int(_ * col_scaling)
-            for _ in range(sbs_col, sbs_col + shape["columns"])
-        ]
+        # the 0-indexed coordinates of all wells in origin plate to be included
+        well_rows = []
+        well_cols = []
+        for idx in range(shape["rows"]):
+            well_row = int(origin_row + idx * row_scaling)
+            well_rows.append(well_row)
+        for idx in range(shape["columns"]):
+            well_col = int(origin_col + idx * col_scaling)
+            well_cols.append(well_col)
 
-        return WellGroup([
-            self.well_from_coordinates(x, y)
-            for x in well_rows for y in well_cols
-        ])
+        # coordinates of the tail (bottom right well) should not exceed bounds
+        tail_row = well_rows[-1]
+        tail_col = well_cols[-1]
+        # tail_row and tail_col are 0-indexed based
+        # container_rows and container_cols are 1-indexed based
+        if tail_row + 1 > container_rows or tail_col + 1 > container_cols:
+            raise ValueError(
+                f"origin: {origin} with shape: {shape} exceeds the bounds of "
+                f"container: {self}"
+            )
+
+        return WellGroup(
+            [self.well_from_coordinates(x, y) for x in well_rows for y in well_cols]
+        )
 
     def __repr__(self):
         """
@@ -1075,5 +1080,7 @@ class Container(object):
         (ex. Container('my_plate'))
 
         """
-        return "Container(%s%s)" % (str(self.name), ", cover=" +
-                                    self.cover if self.cover else "")
+        return (
+            f"Container({str(self.name)}"
+            f"{', cover=' + self.cover if self.cover else ''})"
+        )
