@@ -9,12 +9,11 @@ Contains all the Autoprotocol Instruction objects
 
 # pragma pylint: disable=too-few-public-methods, redefined-builtin
 from .builders import *  # pylint: disable=unused-wildcard-import
+from .constants import PROVISION_MEASUREMENT_MODES
 
 
 class Instruction(object):
-    """Base class for an instruction that is to later be encoded as JSON.
-
-    """
+    """Base class for an instruction that is to later be encoded as JSON."""
 
     builders = InstructionBuilders()
 
@@ -1372,6 +1371,8 @@ class Provision(Instruction):
       Resource ID from catalog.
     dests : list(dict)
       Destination(s) for specified resource, together with volume information
+    measurement_mode : str
+      Measurement mode. Possible values are :py:class:`autoprotocol.constants.MEASUREMENT_MODES`
 
     Raises
     ------
@@ -1380,14 +1381,26 @@ class Provision(Instruction):
     RuntimeError
       If length of the list of volumes specified does not match the number of
       destination wells specified.
+    RuntimeError
+      If the measurement mode is not supported.
     TypeError
       If volume is not specified as a string or Unit (or a list of either)
 
     """
 
-    def __init__(self, resource_id, dests):
+    def __init__(self, resource_id, dests, measurement_mode="volume"):
+        if measurement_mode not in PROVISION_MEASUREMENT_MODES:
+            raise RuntimeError(
+                f"{measurement_mode} is not a valid measurement mode for provisioning"
+            )
+
         super(Provision, self).__init__(
-            op="provision", data={"resource_id": resource_id, "to": dests}
+            op="provision",
+            data={
+                "resource_id": resource_id,
+                "measurement_mode": measurement_mode,
+                "to": dests,
+            },
         )
 
 
