@@ -1,25 +1,21 @@
 """
 Module containing a Units library
 
-    :copyright: 2018 by The Autoprotocol Development Team, see AUTHORS
+    :copyright: 2020 by The Autoprotocol Development Team, see AUTHORS
         for more details.
     :license: BSD, see LICENSE for more details
 
 """
 
-from __future__ import division, print_function
+from collections import defaultdict
+from decimal import Decimal, InvalidOperation
+from numbers import Number
+
+from math import ceil, floor
 from pint import UnitRegistry
+from pint.errors import UndefinedUnitError
 from pint.quantity import _Quantity
 from pint.util import UnitsContainer
-from pint.errors import UndefinedUnitError
-from decimal import Decimal, InvalidOperation
-from collections import defaultdict
-from math import ceil, floor
-from numbers import Number
-import sys
-
-if sys.version_info.major == 3:
-    basestring = str  # pylint: disable=invalid-name
 
 
 def to_decimal(number):
@@ -47,8 +43,9 @@ def to_decimal(number):
         decimal = Decimal(str(number))
     else:
         raise ValueError(
-            "Tried to cast {} to decimal but it was of non-numeric type {}."
-            "".format(number, type(number)))
+            f"Tried to cast {number} to decimal but it was of non-numeric type "
+            f"{type(number)}."
+        )
     return decimal
 
 
@@ -62,18 +59,19 @@ class DecimalUnitRegistry(UnitRegistry):
 
     def _get_root_units(self, input_units, check_nonmult=True):
         if not input_units:
-            return Decimal('1'), UnitsContainer()
+            return Decimal("1"), UnitsContainer()
 
         # The cache is only done for check_nonmult=True
         if check_nonmult and input_units in self._root_units_cache:
             return self._root_units_cache[input_units]
 
-        accumulators = [Decimal('1'), defaultdict(Decimal)]
-        self._get_root_units_recurse(input_units, Decimal('1'), accumulators)
+        accumulators = [Decimal("1"), defaultdict(Decimal)]
+        self._get_root_units_recurse(input_units, Decimal("1"), accumulators)
 
         factor = accumulators[0]
-        units = UnitsContainer(dict(
-            (k, v) for k, v in accumulators[1].items() if v != Decimal('0')))
+        units = UnitsContainer(
+            dict((k, v) for k, v in accumulators[1].items() if v != Decimal("0"))
+        )
 
         if check_nonmult:
             for unit in units.keys():
@@ -93,16 +91,15 @@ class DecimalUnitRegistry(UnitRegistry):
             if reg.is_base:
                 accumulators[1][key] += exp2
             else:
-                accumulators[0] *= (to_decimal(reg._converter.scale) ** exp2)
+                accumulators[0] *= to_decimal(reg._converter.scale) ** exp2
                 if reg.reference is not None:
-                    self._get_root_units_recurse(
-                        reg.reference, exp2, accumulators)
+                    self._get_root_units_recurse(reg.reference, exp2, accumulators)
 
 
 # Preload UnitRegistry (Use default Pints definition file as a base)
 _UnitRegistry = DecimalUnitRegistry()
 
-'''Map string representation of Pint units over to Autoprotocol format'''
+"""Map string representation of Pint units over to Autoprotocol format"""
 # Map Temperature Unit names
 _UnitRegistry._units["degC"]._name = "celsius"
 _UnitRegistry._units["celsius"]._name = "celsius"
@@ -113,8 +110,8 @@ _UnitRegistry._units["rankine"]._name = "rankine"
 # Map Speed Unit names
 _UnitRegistry._units["revolutions_per_minute"]._name = "rpm"
 
-'''Add support for Molarity Unit'''
-_UnitRegistry.define('molar = mole/liter = M')
+"""Add support for Molarity Unit"""
+_UnitRegistry.define("molar = mole/liter = M")
 # pragma pylint: enable=protected-access
 
 
@@ -131,18 +128,21 @@ class UnitError(Exception):
 
 
 class UnitStringError(UnitError):
-    message_text = ("Invalid format '%s'; when building a Unit from a string "
-                    "it must be formatted as '1:meter'.")
+    message_text = (
+        "Invalid format '%s'; when building a Unit from a string "
+        "it must be formatted as '1:meter'."
+    )
 
 
 class UnitValueError(UnitError):
-    message_text = ("Invalid value '%s'; when building a Unit "
-                    "the value must be numeric.")
+    message_text = "Invalid value '%s'; when building a Unit the value must be numeric."
 
 
 class UnitUnitsError(UnitError):
-    message_text = ("Invalid value '%s'; when building a Unit "
-                    "the units must be in the UnitRegistry.")
+    message_text = (
+        "Invalid value '%s'; when building a Unit "
+        "the units must be in the UnitRegistry."
+    )
 
 
 class Unit(_Quantity):
@@ -182,6 +182,7 @@ class Unit(_Quantity):
             0.036:liter / hour
 
     """
+
     def __new__(cls, value, units=None):
         cls._REGISTRY = _UnitRegistry
         cls.force_ndarray = False
@@ -191,7 +192,7 @@ class Unit(_Quantity):
             return value
 
         # Automatically parse String if no units provided
-        if not units and isinstance(value, basestring):
+        if not units and isinstance(value, str):
             try:
                 value, units = value.split(":")
             except ValueError:
@@ -224,10 +225,10 @@ class Unit(_Quantity):
         rounded_magnitude = round(self.magnitude, ndigits)
         normalized_magnitude = to_decimal(rounded_magnitude).normalize()
         unit_repr = self.unit.replace("**", "^").replace(" ", "")
-        return "{:f}:{:s}".format(normalized_magnitude, unit_repr)
+        return f"{normalized_magnitude:f}:{unit_repr:s}"
 
     def __repr__(self):
-        return "Unit({:f}, '{:s}')".format(self.magnitude, self.units)
+        return f"Unit({self.magnitude:f}, '{self.units:s}')"
 
     def __ceil__(self):
         return self.__class__(ceil(self.magnitude), self.units)
@@ -273,9 +274,9 @@ class Unit(_Quantity):
             self._magnitude = to_decimal(magnitude)
         except ValueError:
             raise RuntimeError(
-                "Tried to set Unit's magnitude {} but it was of type {}. "
-                "Magnitudes must be numeric.".format(
-                    magnitude, type(magnitude)))
+                f"Tried to set Unit's magnitude {magnitude} but it was of type "
+                f"{type(magnitude)}. Magnitudes must be numeric."
+            )
 
     @staticmethod
     def fromstring(s):
